prove_stacked_opening_reduction

Function prove_stacked_opening_reduction 

pub fn prove_stacked_opening_reduction<'a, SC, PB, PD, TS, SRP>(
    device: &'a PD,
    transcript: &mut TS,
    n_stack: usize,
    stacked_per_commit: Vec<&'a PB::PcsData>,
    need_rot_per_commit: Vec<Vec<bool>>,
    r: &[PB::Challenge],
) -> (StackingProof<SC>, Vec<PB::Challenge>)
where SC: StarkProtocolConfig, PB: ProverBackend<Val = SC::F, Challenge = SC::EF>, TS: FiatShamirTranscript<SC>, SRP: StackedReductionProver<'a, PB, PD>,
Batch sumcheck to reduce trace openings, including rotations, to stacked matrix opening.

The stacked_matrix, stacked_layout should be the result of stacking the traces with parameters l_skip and n_stack.